# Examples

This directory contains examples on how to use Manen for web automation, scraping or testing. Each example defines a set of Manen `Page` and `Component` before using it in the main script.

| Site name                       | Links                                                                                               | Topic                                                        |
| ------------------------------- | --------------------------------------------------------------------------------------------------- | ------------------------------------------------------------ |
| PyPI                            | [Example](./pypi/pypi.py) - [Site](https://pypi.org/)                                               | Form submission and results parsing                          |
| Scrape this site - Countries    | [Example](./scrape_this_site/countries.py) - [Site](https://www.scrapethissite.com/pages/simple/)   | Extracting organized data from a list                        |
| Scrape this site - Hockey Teams | [Example](./scrape_this_site/hockey_teams.py) - [Site](https://www.scrapethissite.com/pages/forms/) | Extracting data from a table after a form submission         |
| Books to Scrape                 | [Example](./to_scrape/books.py) - [Site](https://books.toscrape.com/)                               | Extracting paginated search results and exploring categories |
| Quotes to Scrape                | [Example](./to_scrape/quotes.py) - [Site](https://quotes.toscrape.com/)                             | Extracting paginated search results and getting tags         |
